@@ -448,7 +448,7 @@ class Stark(Client, Mechanism):
     def activate(user: "Stark" = None, bot: "Stark" = None):
         try:
             if not user:
-                user = Stark()
+                user = [Stark(s) for s in env.SESSIONS]
             if not bot:
                 bot = Stark(is_bot=True)
             user = [user] if not isinstance(user, list) else user
